@@ -5,6 +5,7 @@ from classiq_interface.backend.backend_preferences import (
     BackendPreferences,
     IBMBackendPreferences,
 )
+from classiq_interface.chemistry import operator
 from classiq_interface.combinatorial_optimization import (
     model_serializer,
     optimization_problem,
@@ -60,3 +61,14 @@ class CombinatorialOptimization:
             raise Exception(f"Solving failed: {result.details}")
 
         return result
+
+    async def get_operator(self) -> operator.OperatorResult:
+        wrapper = api_wrapper.ApiWrapper()
+        result = await wrapper.call_combinatorial_optimization_operator_task(
+            problem=self._problem
+        )
+
+        if result.status != operator.OperatorStatus.SUCCESS:
+            raise Exception(f"Get operator failed: {result.details}")
+
+        return result
